@@ -475,9 +475,9 @@ def _process_doc(
     #
     cli_args = [
         XMLLINT_PATH,
-        "--schema",
-        RESOURCES_PATH + "schema/teix.xsd",
-        doc_file_no_extension + "_09_tei_openedition.xml",
+        "--relaxng",
+        RESOURCES_PATH + "schema/tei_lite.rng",
+        doc_file_no_extension + "_08_tei_metopes.xml",
         "--noout",
     ]
     logger.debug(" ".join(cli_args))
@@ -490,14 +490,14 @@ def _process_doc(
     if p.returncode != 0:
         logger.error(
             "Validate {} {}".format(
-                os.path.basename(doc_file_no_extension + "_09_tei_openedition.xml"),
+                os.path.basename(doc_file_no_extension + "_08_tei_metopes.xml"),
                 _union_java_output(out, err),
             )
         )
     else:
         logger.info(
             "Validate {}".format(
-                os.path.basename(doc_file_no_extension + "_09_tei_openedition.xml validates")
+                os.path.basename(doc_file_no_extension + "_08_tei_metopes.xml validates")
             )
         )
 
